<?php
/**
 * Add color options in Customizer
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */

$wp_customize->add_panel( 'helena_color_options', array(
    'capability'     => 'edit_theme_options',
    'description'    => esc_html__( 'Color Options', 'helena-pro' ),
    'priority'       => 300,
    'title'    		 => esc_html__( 'Color Options', 'helena-pro' ),
) );

$wp_customize->add_setting( 'color_scheme', array(
	'capability' 		=> 'edit_theme_options',
	'default'    		=> $defaults['color_scheme'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'color_scheme', array(
	'choices'  => helena_color_schemes(),
	'label'    => esc_html__( 'Color Scheme', 'helena-pro' ),
	'priority' => 5,
	'section'  => 'helena_basic_color',
	'settings' => 'color_scheme',
	'type'     => 'radio',
) );

$color_headings = apply_filters( 'helena_color_options', 'color_headings' );

foreach ( $color_headings as $key_section => $title_section ) {
	$color_options	= apply_filters( 'helena_color_options', $key_section );

	$wp_customize->add_section( 'helena_' . $key_section, array(
		'panel' => 'helena_color_options',
		'title' => $title_section,
	) );

	$i = 10;
	foreach ( $color_options as $key => $label ) {
		$wp_customize->add_setting( $key, array(
			'capability'        => 'edit_theme_options',
			'default'           => $defaults[ $key ],
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, $key, array(
			'label'    => $label,
			'priority' => $i,
			'section'  => 'helena_' . $key_section,
			'settings' => $key,
		) ) );
		$i += 10;
	}
}

$wp_customize->add_setting( 'social_menu_brand_color', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['social_menu_brand_color'],
	'sanitize_callback' => 'sanitize_key',
) );

$wp_customize->add_control( 'social_menu_brand_color', array(
	'choices'=> array(
		'disable'      => '--'. esc_html__( 'Select', 'helena-pro' ). '--',
		'hover'        => esc_html__( 'hover', 'helena-pro' ),
		'hover-static' => esc_html__( 'hover and static', 'helena-pro' )
	),
	'label'		=> esc_html__( 'Enable Social Icon\'s Brand Color on', 'helena-pro' ),
	'priority'	=> 100,
	'section'   => 'helena_social_color',
    'settings'  => 'social_menu_brand_color',
	'type'		=> 'select',
) );

$wp_customize->add_setting( 'header_highlight_small_note', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_image',
) );

$wp_customize->add_control( new helena_note_control( $wp_customize, 'header_highlight_small_note', array(
	'label'    => esc_html__( 'Small Content color options for desktop view', 'helena-pro' ),
	'priority' => 115,
	'section'  => 'helena_header_highlight_color',
	'settings' => 'header_highlight_small_note',
	'type'     => 'description',
) ) );