<?php
/**
* Add Header Highlight Content in Customizer
*
* @package Catch Themes
* @subpackage Helena Pro
* @since Helena Pro 1.0
*/

$wp_customize->add_section( 'helena_header_highlight_content', array(
	'priority' => 600,
	'title'    => esc_html__( 'Header Highlight Content', 'helena-pro' ),
) );

$wp_customize->add_setting( 'header_highlight_content_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['header_highlight_content_option'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'header_highlight_content_option', array(
	'choices'  	=> helena_featured_section_enable_options(),
	'label'    	=> esc_html__( 'Enable Header Highlight Content on', 'helena-pro' ),
	'priority'	=> '1',
	'section'  	=> 'helena_header_highlight_content',
	'settings' 	=> 'header_highlight_content_option',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'header_highlight_content_type', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['header_highlight_content_type'],
	'sanitize_callback'	=> 'helena_sanitize_select',
) );

$wp_customize->add_control( 'header_highlight_content_type', array(
	'active_callback' => 'helena_is_header_highlight_content_active',
	'choices'         => helena_header_highlight_content_types(),
	'label'           => esc_html__( 'Select Content Type', 'helena-pro' ),
	'priority'        => '3',
	'section'         => 'helena_header_highlight_content',
	'settings'        => 'header_highlight_content_type',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'header_highlight_content_headline', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'wp_kses_post',
) );

$wp_customize->add_control( 'header_highlight_content_headline' , array(
	'active_callback'	=> 'helena_is_header_highlight_content_active',
	'description'	=> esc_html__( 'Leave field empty if you want to remove Headline', 'helena-pro' ),
	'label'    		=> esc_html__( 'Headline for Header Highlight Content', 'helena-pro' ),
	'priority'		=> '4',
	'section'  		=> 'helena_header_highlight_content',
	'settings' 		=> 'header_highlight_content_headline',
	'type'	   		=> 'text',
	)
);

$wp_customize->add_setting( 'header_highlight_content_subheadline', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'wp_kses_post',
) );

$wp_customize->add_control( 'header_highlight_content_subheadline' , array(
	'active_callback'	=> 'helena_is_header_highlight_content_active',
	'description'	=> esc_html__( 'Leave field empty if you want to remove Sub-headline', 'helena-pro' ),
	'label'    		=> esc_html__( 'Sub-headline for Header Highlight Content', 'helena-pro' ),
	'priority'		=> '5',
	'section'  		=> 'helena_header_highlight_content',
	'settings' 		=> 'header_highlight_content_subheadline',
	'type'	   		=> 'text',
	)
);

$wp_customize->add_setting( 'header_highlight_content_show', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['header_highlight_content_show'],
	'sanitize_callback'	=> 'helena_sanitize_select',
) );

$wp_customize->add_control( 'header_highlight_content_show', array(
	'active_callback' => 'helena_is_demo_header_highlight_content_inactive',
	'choices'         => helena_featured_content_show(),
	'label'           => esc_html__( 'Display Content', 'helena-pro' ),
	'section'         => 'helena_header_highlight_content',
	'settings'        => 'header_highlight_content_show',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'header_highlight_content_number', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['header_highlight_content_number'],
	'sanitize_callback'	=> 'helena_sanitize_number_range',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'header_highlight_content_number' , array(
		'active_callback' => 'helena_is_demo_header_highlight_content_inactive',
		'description'     => esc_html__( 'Save and refresh the page if No. of Header Highlight Content is changed', 'helena-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 45px;',
			'min'   => 0,
			'step'  => 1,
		),
		'label'           => esc_html__( 'No of Header Highlight Content', 'helena-pro' ),
		'priority'        => '6',
		'section'         => 'helena_header_highlight_content',
		'settings'        => 'header_highlight_content_number',
		'type'            => 'number',
	)
);

$wp_customize->add_setting( 'header_highlight_content_select_category', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_category_list',
) );

$wp_customize->add_control( new helena_Customize_Dropdown_Categories_Control( $wp_customize, 'helena_header_highlight_content_select_category', array(
	'active_callback' => 'helena_is_header_highlight_category_content_active',
	'label'           => esc_html__( 'Select Categories', 'helena-pro' ),
	'name'            => 'header_highlight_content_select_category',
	'section'         => 'helena_header_highlight_content',
	'settings'        => 'header_highlight_content_select_category',
	'type'            => 'dropdown-categories',
) ) );

$wp_customize->add_setting( 'header_highlight_content_hide_category', array(
    'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_checkbox',
) );

$wp_customize->add_control(  'header_highlight_content_hide_category', array(
	'active_callback' => 'helena_is_post_category_header_highlight_content_inactive',
	'label'           => esc_html__( 'Check to Hide Category Meta', 'helena-pro' ),
	'section'         => 'helena_header_highlight_content',
	'settings'        => 'header_highlight_content_hide_category',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'header_highlight_content_hide_tags', array(
    'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_checkbox',
) );

$wp_customize->add_control(  'header_highlight_content_hide_tags', array(
	'active_callback' => 'helena_is_post_category_header_highlight_content_inactive',
	'label'           => esc_html__( 'Check to Hide Tag Meta', 'helena-pro' ),
	'section'         => 'helena_header_highlight_content',
	'settings'        => 'header_highlight_content_hide_tags',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'header_highlight_content_hide_date', array(
    'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_checkbox',
) );

$wp_customize->add_control(  'header_highlight_content_hide_date', array(
	'active_callback' => 'helena_is_post_category_header_highlight_content_inactive',
	'label'           => esc_html__( 'Check to Hide Posted On Date', 'helena-pro' ),
	'section'         => 'helena_header_highlight_content',
	'settings'        => 'header_highlight_content_hide_date',
	'type'            => 'checkbox',
) );

if ( is_multi_author() ) {
    $wp_customize->add_setting( 'header_highlight_content_hide_author', array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'header_highlight_content_hide_author', array(
		'active_callback' => 'helena_is_post_category_header_highlight_content_inactive',
		'label'           => esc_html__( 'Check to Hide Author Meta', 'helena-pro' ),
		'section'         => 'helena_header_highlight_content',
		'settings'        => 'header_highlight_content_hide_author',
		'type'            => 'checkbox',
    ) );
}

$number = apply_filters( 'helena_get_option', 'header_highlight_content_number' );
//loop for content types
for ( $i=1; $i <= $number ; $i++ ) {

	//Post Content
	$wp_customize->add_setting( 'header_highlight_content_post_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_page',
		)
	);

	$wp_customize->add_control( 'helena_header_highlight_content_post_'. $i, array(
		'active_callback' => 'helena_is_header_highlight_post_content_active',
		'input_attrs'     => array(
			'style' => 'width: 200px;'
		),
		'label'           => esc_html__( 'Post', 'helena-pro' ) . ' ' . $i ,
		'section'         => 'helena_header_highlight_content',
		'settings'        => 'header_highlight_content_post_'. $i,
		'type'            => 'text',
		)
	);


	//Page Content
	$wp_customize->add_setting( 'header_highlight_content_page_'. $i, array(
		'capability'        => 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_page',
	) );

	$wp_customize->add_control( 'header_highlight_content_page_'. $i, array(
		'active_callback' => 'helena_is_header_highlight_page_content_active',
		'label'           => esc_html__( 'Page', 'helena-pro' ) . ' ' . $i ,
		'section'         => 'helena_header_highlight_content',
		'settings'        => 'header_highlight_content_page_'. $i,
		'type'            => 'dropdown-pages',
	) );

	//Image Content
	$wp_customize->add_setting( 'header_highlight_content_note_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new helena_Note_Control( $wp_customize, 'header_highlight_content_note_'. $i, array(
		'active_callback' => 'helena_is_header_highlight_image_content_active',
		'label'           => esc_html__( 'Header Highlight Content #', 'helena-pro' ) .  $i,
		'section'         => 'helena_header_highlight_content',
		'settings'        => 'header_highlight_content_note_'. $i,
		'type'            => 'description',
		) ) );

	$wp_customize->add_setting( 'header_highlight_content_image_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'header_highlight_content_image_'. $i, array(
		'active_callback' => 'helena_is_header_highlight_image_content_active',
		'label'           => esc_html__( 'Image', 'helena-pro' ),
		'section'         => 'helena_header_highlight_content',
		'settings'        => 'header_highlight_content_image_'. $i,
	) ) );

	$wp_customize->add_setting( 'header_highlight_content_link_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'header_highlight_content_link_'. $i, array(
		'active_callback' => 'helena_is_header_highlight_image_content_active',
		'label'           => esc_html__( 'Link', 'helena-pro' ),
		'section'         => 'helena_header_highlight_content',
		'settings'        => 'header_highlight_content_link_'. $i,
	) );

	$wp_customize->add_setting( 'header_highlight_content_target_'. $i, array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'header_highlight_content_target_'. $i, array(
		'active_callback' => 'helena_is_header_highlight_image_content_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'helena-pro' ),
		'section'         => 'helena_header_highlight_content',
		'settings'        => 'header_highlight_content_target_'. $i,
		'type'            => 'checkbox',
    ) );

    $wp_customize->add_setting( 'header_highlight_content_title_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'header_highlight_content_title_'. $i, array(
		'active_callback' => 'helena_is_header_highlight_image_content_active',
		'label'           => esc_html__( 'Title', 'helena-pro' ),
		'section'         => 'helena_header_highlight_content',
		'settings'        => 'header_highlight_content_title_'. $i,
		'type'            => 'text',
    ) );

    $wp_customize->add_setting( 'header_highlight_content_content_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'header_highlight_content_content_'. $i, array(
			'active_callback' => 'helena_is_header_highlight_image_content_active',
			'label'           => esc_html__( 'Content', 'helena-pro' ),
			'section'         => 'helena_header_highlight_content',
			'settings'        => 'header_highlight_content_content_'. $i,
			'type'            => 'textarea',
    ) );

    $wp_customize->add_setting( 'header_highlight_content_button_text_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'header_highlight_content_button_text_'. $i, array(
			'active_callback' => 'helena_is_header_highlight_image_content_active',
			'label'           => esc_html__( 'Button Text', 'helena-pro' ),
			'section'         => 'helena_header_highlight_content',
			'settings'        => 'header_highlight_content_button_text_'. $i,
	) );

	$wp_customize->add_setting( 'header_highlight_content_button_link_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control( 'header_highlight_content_button_link_'. $i, array(
			'active_callback' => 'helena_is_header_highlight_image_content_active',
			'label'           => esc_html__( 'Button Link', 'helena-pro' ),
			'section'         => 'helena_header_highlight_content',
			'settings'        => 'header_highlight_content_button_link_'. $i,
	) );


	$wp_customize->add_setting( 'header_highlight_content_button_target_'. $i, array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'header_highlight_content_button_target_'. $i, array(
		'active_callback' => 'helena_is_header_highlight_image_content_active',
		'label'           => esc_html__( 'Check to Open Button Link in New Window/Tab', 'helena-pro' ),
		'section'         => 'helena_header_highlight_content',
		'settings'        => 'header_highlight_content_button_target_'. $i,
		'type'            => 'checkbox',
    ) );

    //Embed Content
    $wp_customize->add_setting( 'header_highlight_content_embed_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'wp_kses_post',
	) );

	$wp_customize->add_control( 'header_highlight_content_embed_'. $i, array(
			'active_callback' => 'helena_is_header_highlight_embed_content_active',
			'label'           => esc_html__( 'Embed Content', 'helena-pro' ) . ' ' . $i ,
			'section'         => 'helena_header_highlight_content',
			'settings'        => 'header_highlight_content_embed_'. $i,
			'type'            => 'textarea',
    ) );
}
