<?php
/**
 * Add Logo Slider Options in Customizer
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */

//Logo Slider
$wp_customize->add_section( 'helena_logo_slider', array(
	'priority' => 800,
	'title'    => esc_html__( 'Logo Slider', 'helena-pro' ),
) );

$wp_customize->add_setting( 'logo_slider_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_option'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'logo_slider_option', array(
	'choices'  => helena_featured_section_enable_options(),
	'label'    => esc_html__( 'Enable Logo Slider on', 'helena-pro' ),
	'section'  => 'helena_logo_slider',
	'settings' => 'logo_slider_option',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'logo_slider_type', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_type'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'logo_slider_type', array(
	'active_callback' => 'helena_is_logo_slider_active',
	'choices'         => helena_logo_slider_types(),
	'label'           => esc_html__( 'Logo Slider Type', 'helena-pro' ),
	'section'         => 'helena_logo_slider',
	'settings'        => 'logo_slider_type',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'logo_slider_transition_delay', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_transition_delay'],
	'sanitize_callback'	=> 'helena_sanitize_number_range',
) );

$wp_customize->add_control( 'logo_slider_transition_delay' , array(
	'active_callback' => 'helena_is_logo_slider_active',
	'description'     => esc_html__( 'seconds(s)', 'helena-pro' ),
	'input_attrs'     => array(
		'style' => 'width: 100px;'
		),
	'label'           => esc_html__( 'Transition Delay', 'helena-pro' ),
	'section'         => 'helena_logo_slider',
	'settings'        => 'logo_slider_transition_delay',
) );

$wp_customize->add_setting( 'logo_slider_transition_length', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_transition_length'],
	'sanitize_callback'	=> 'helena_sanitize_number_range',
) );

$wp_customize->add_control( 'logo_slider_transition_length' , array(
		'active_callback' => 'helena_is_logo_slider_active',
		'description'     => esc_html__( 'seconds(s)', 'helena-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 100px;'
		),
		'label'           => esc_html__( 'Transition Length', 'helena-pro' ),
		'section'         => 'helena_logo_slider',
		'settings'        => 'logo_slider_transition_length',
	)
);

$wp_customize->add_setting( 'logo_slider_title', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_title'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'logo_slider_title' , array(
	'active_callback' => 'helena_is_demo_logo_slider_inactive',
	'label'           => esc_html__( 'Title', 'helena-pro' ),
	'section'         => 'helena_logo_slider',
	'settings'        => 'logo_slider_title',
) );

$wp_customize->add_setting( 'logo_slider_number', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_number'],
	'sanitize_callback'	=> 'helena_sanitize_number_range',
) );

$wp_customize->add_control( 'logo_slider_number' , array(
	'active_callback' => 'helena_is_demo_logo_slider_inactive',
	'description'     => esc_html__( 'Save and refresh the page if No. of Slides is changed (Max no of slides is 20)', 'helena-pro' ),
	'input_attrs'     => array(
	'style'           => 'width: 45px;',
		'min'  => 0,
		'max'  => 20,
		'step' => 1,
	),
	'label'           => esc_html__( 'No of Items', 'helena-pro' ),
	'section'         => 'helena_logo_slider',
	'settings'        => 'logo_slider_number',
	'type'            => 'number',
	)
);

$wp_customize->add_setting( 'logo_slider_visible_items', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['logo_slider_visible_items'],
	'sanitize_callback' => 'helena_sanitize_number_range',
) );

$wp_customize->add_control( 'logo_slider_visible_items', array(
	'active_callback' => 'helena_is_demo_logo_slider_inactive',
	'input_attrs'     => array(
	'style'           => 'width: 45px;',
		'min'  => 0,
		'max'  => 5,
		'step' => 1,
	),
	'label'           => esc_html__( 'No of visible items', 'helena-pro' ),
	'section'         => 'helena_logo_slider',
	'settings'        => 'logo_slider_visible_items',
	'type'            => 'number',
) );

$wp_customize->add_setting( 'logo_slider_select_category', array(
	'capability'		=> 'edit_theme_options',
	'sanitize_callback'	=> 'helena_sanitize_category_list',
) );

$wp_customize->add_control( new helena_customize_dropdown_categories_control( $wp_customize, 'helena_logo_slider_select_category', array(
	'active_callback' => 'helena_is_logo_category_slider_active',
	'label'           => esc_html__( 'Select Categories', 'helena-pro' ),
	'name'            => 'logo_slider_select_category',
	'section'         => 'helena_logo_slider',
	'settings'        => 'logo_slider_select_category',
	'type'            => 'dropdown-categories',
) ) );

//loop for featured post sliders
$number = apply_filters( 'helena_get_option', 'logo_slider_number' );
for ( $i=1; $i <= $number ; $i++ ) {
	//post content
	$wp_customize->add_setting( 'logo_slider_post_'. $i, array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'helena_sanitize_page',
		)
	);

	$wp_customize->add_control( 'helena_logo_slider_post_'. $i, array(
		'active_callback' => 'helena_is_logo_post_slider_active',
		'input_attrs'     => array( 'style' => 'width: 100px;'),
		'label'           => esc_html__( 'Post', 'helena-pro' ) . ' ' . $i ,
		'section'         => 'helena_logo_slider',
		'settings'        => 'logo_slider_post_'. $i,
		'type'            => 'text',
	) );

	//page content
	$wp_customize->add_setting( 'logo_slider_page_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_page',
	) );

	$wp_customize->add_control( 'helena_logo_slider_page_'. $i, array(
		'active_callback' => 'helena_is_logo_page_slider_active',
		'label'           => esc_html__( 'Page', 'helena-pro' ) . ' ' . $i ,
		'section'         => 'helena_logo_slider',
		'settings'        => 'logo_slider_page_'. $i,
		'type'            => 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'logo_slider_note_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new helena_note_control( $wp_customize, 'logo_slider_note_'. $i, array(
		'active_callback' => 'helena_is_logo_image_slider_active',
		'label'           => esc_html__( 'Slide #', 'helena-pro' ) . $i,
		'section'         => 'helena_logo_slider',
		'settings'        => 'logo_slider_note_'. $i,
		'type'            => 'description',
	) ) );

	$wp_customize->add_setting( 'logo_slider_image_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo_slider_image_'. $i , array(
		'active_callback' => 'helena_is_logo_image_slider_active',
		'label'           => esc_html__( 'Image', 'helena-pro' ),
		'section'         => 'helena_logo_slider',
		'settings'        => 'logo_slider_image_'. $i,
	) ) );

	$wp_customize->add_setting( 'logo_slider_title_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'logo_slider_title_'. $i, array(
		'active_callback' => 'helena_is_logo_image_slider_active',
		'label'           => esc_html__( 'Title/Image Alt', 'helena-pro' ),
		'section'         => 'helena_logo_slider',
		'settings'        => 'logo_slider_title_'. $i,
	) );

	$wp_customize->add_setting( 'logo_slider_link_'. $i, array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'logo_slider_link_'. $i, array(
		'active_callback' => 'helena_is_logo_image_slider_active',
		'label'           => esc_html__( 'Link', 'helena-pro' ),
		'section'         => 'helena_logo_slider',
		'settings'        => 'logo_slider_link_'. $i,
	) );

	$wp_customize->add_setting( 'logo_slider_target_'. $i, array(
        'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'helena_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'logo_slider_target_'. $i, array(
		'active_callback' => 'helena_is_logo_image_slider_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'helena-pro' ),
		'section'         => 'helena_logo_slider',
		'settings'        => 'logo_slider_target_'. $i,
		'type'            => 'checkbox',
    ) );
}
// Logo Slider End