<?php
/**
* Add additional theme options in Customizer
*
* @package Catch Themes
* @subpackage Helena Pro
* @since Helena Pro 1.0
*/

$wp_customize->add_panel( 'helena_theme_options', array(
    'description'    => esc_html__( 'Basic theme Options', 'helena-pro' ),
    'capability'     => 'edit_theme_options',
    'priority'       => 200,
    'title'    		 => esc_html__( 'Theme Options', 'helena-pro' ),
) );

// Breadcrumb Option
$wp_customize->add_section( 'helena_breadcrumb_options', array(
	'description'	=> esc_html__( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance. You can enable/disable them on homepage and entire site.', 'helena-pro' ),
	'panel'			=> 'helena_theme_options',
	'title'    		=> esc_html__( 'Breadcrumb Options', 'helena-pro' ),
	'priority' 		=> 201,
) );

$wp_customize->add_setting( 'breadcrumb_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcrumb_option'],
	'sanitize_callback' => 'helena_sanitize_checkbox'
) );

$wp_customize->add_control( 'breadcrumb_option', array(
	'label'    => esc_html__( 'Check to enable Breadcrumb', 'helena-pro' ),
	'section'  => 'helena_breadcrumb_options',
	'settings' => 'breadcrumb_option',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'breadcrumb_on_homepage', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcrumb_on_homepage'],
	'sanitize_callback' => 'helena_sanitize_checkbox'
) );

$wp_customize->add_control( 'breadcrumb_on_homepage', array(
	'label'    => esc_html__( 'Check to enable Breadcrumb on Homepage', 'helena-pro' ),
	'section'  => 'helena_breadcrumb_options',
	'settings' => 'breadcrumb_on_homepage',
	'type'     => 'checkbox',
) );

$wp_customize->add_setting( 'breadcrumb_seperator', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['breadcrumb_seperator'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'breadcrumb_seperator', array(
	'input_attrs' => array(
    		'style' => 'width: 100px;'
		),
	'label'    	=> esc_html__( 'Separator between Breadcrumbs', 'helena-pro' ),
	'section' 	=> 'helena_breadcrumb_options',
	'settings' 	=> 'breadcrumb_seperator',
	'type'     	=> 'text'
	)
);
	// Breadcrumb Option End

	// Comment Option
$wp_customize->add_section( 'helena_comment_option', array(
	'description'	=> esc_html__( 'Comments can also be disabled on a per post/page basis when creating/editing posts/pages.', 'helena-pro' ),
	'panel' 		=> 'helena_theme_options',
	'priority'		=> 202,
	'title'   		=> esc_html__( 'Comment Options', 'helena-pro' ),
) );

$wp_customize->add_setting( 'comment_option', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['comment_option'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'comment_option', array(
		'choices'  	=> helena_comment_options(),
		'label'		=> esc_html__( 'Comment Option', 'helena-pro' ),
        'priority'	=> 1,
		'section'   => 'helena_comment_option',
        'settings'  => 'comment_option',
        'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'disable_website_field', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['disable_website_field'],
	'sanitize_callback' => 'helena_sanitize_checkbox',
) );

$wp_customize->add_control( 'disable_website_field', array(
	'label'		=> esc_html__( 'Check to Disable Website Field', 'helena-pro' ),
	'section'   => 'helena_comment_option',
    'settings'  => 'disable_website_field',
	'type'		=> 'checkbox',
) );
	// Comment End

	// Custom CSS Option
$wp_customize->add_section( 'helena_custom_css', array(
	'description'	=> esc_html__( 'Custom/Inline CSS', 'helena-pro'),
	'panel'  		=> 'helena_theme_options',
	'priority' 		=> 203,
	'title'    		=> esc_html__( 'Custom CSS Options', 'helena-pro' ),
) );

$wp_customize->add_setting( 'custom_css', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['custom_css'],
	'sanitize_callback' => 'helena_sanitize_custom_css',
) );

$wp_customize->add_control( 'custom_css', array(
		'label'		=> esc_html__( 'Enter Custom CSS', 'helena-pro' ),
        'priority'	=> 1,
		'section'   => 'helena_custom_css',
        'settings'  => 'custom_css',
		'type'		=> 'textarea',
) );
	// Custom CSS End

	// Excerpt Options
$wp_customize->add_section( 'helena_excerpt_options', array(
	'panel'  	=> 'helena_theme_options',
	'priority' 	=> 204,
	'title'    	=> esc_html__( 'Excerpt Options', 'helena-pro' ),
) );

$wp_customize->add_setting( 'excerpt_length', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['excerpt_length'],
	'sanitize_callback' => 'helena_sanitize_number_range',
) );

$wp_customize->add_control( 'excerpt_length', array(
	'description' => esc_html__( 'Excerpt length. Default is 40 words', 'helena-pro'),
	'input_attrs' => array(
        'min'   => 10,
        'max'   => 200,
        'step'  => 5,
        'style' => 'width: 60px;'
        ),
    'label'    => esc_html__( 'Excerpt Length (words)', 'helena-pro' ),
	'section'  => 'helena_excerpt_options',
	'settings' => 'excerpt_length',
	'type'	   => 'number',
	)
);

$wp_customize->add_setting( 'excerpt_more_text', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['excerpt_more_text'],
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( 'excerpt_more_text', array(
	'label'    => esc_html__( 'Read More Text', 'helena-pro' ),
	'section'  => 'helena_excerpt_options',
	'settings' => 'excerpt_more_text',
	'type'	   => 'text',
) );
// Excerpt Options End

// Feed Redirect
$wp_customize->add_section( 'helena_feed_redirect', array(
	'panel'			=> 'helena_theme_options',
	'description'	=> esc_html__( 'If your custom feed(s) are not handled by Feedblitz or Feedburner, do not use the redirect options.', 'helena-pro' ),
	'priority' 		=> 205,
	'title'    		=> esc_html__( 'Feed Redirect', 'helena-pro' ),
) );

$wp_customize->add_setting( 'feed_redirect', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['feed_redirect'],
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'feed_redirect', array(
	'label'    => esc_html__( 'Feed Redirect', 'helena-pro' ),
	'section'  => 'helena_feed_redirect',
	'settings' => 'feed_redirect',
	'type'	   => 'text',
) );
// Feed Redirect End

// Font Family Options
$wp_customize->add_section( 'helena_font_family', array(
	'panel'  => 'helena_theme_options',
	'priority'	=> 207,
	'title'    	=> esc_html__( 'Font Family Options', 'helena-pro' ),
) );

$avaliable_fonts = helena_avaliable_fonts();

$choices = array();

foreach ( $avaliable_fonts as $avaliable_font ) {
	$choices[ $avaliable_font[ 'value' ] ] = str_replace( '"', '', $avaliable_font[ 'label' ] );
}

$font_family_options	=	array(
									'title_font' 		=> esc_html__( 'Site Title Font Family', 'helena-pro' ),
									'body_font' 		=> esc_html__( 'Default Font Family', 'helena-pro' ),
									'tagline_font' 		=> esc_html__( 'Site Tagline Font Family', 'helena-pro' ),
									'content_title_font'=> esc_html__( 'Content Title Font Family', 'helena-pro' ),
									'content_font' 		=> esc_html__( 'Content Body Font Family', 'helena-pro' ),
									'headings_font' 	=> esc_html__( 'Headings Tags from h1 to h6 Font Family', 'helena-pro' )
								);

foreach ( $font_family_options as $key => $font_family_option ) {
	$wp_customize->add_setting( $key, array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults[ $key ],
		'sanitize_callback' => 'helena_sanitize_select',
	) );

	$wp_customize->add_control( $key, array(
		'choices'  => $choices,
		'label'    => $font_family_option,
		'section'  => 'helena_font_family',
		'settings' => $key,
		'type'     => 'select',
	) );
}

$wp_customize->add_setting( 'reset_typography', array(
	'capability'        => 'edit_theme_options',
	'default'           => $defaults['reset_typography'],
	'sanitize_callback' => 'helena_sanitize_checkbox',
	'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'reset_typography', array(
	'label'    => esc_html__( 'Check to reset fonts', 'helena-pro' ),
	'section'  => 'helena_font_family',
	'settings' => 'reset_typography',
	'type'     => 'checkbox',
) );
// Font Family Options End

// Footer Editor Options
$wp_customize->add_section( 'helena_footer_options', array(
	'description'	=> esc_html__( 'You can either add html or plain text', 'helena-pro'),
	'panel'  => 'helena_theme_options',
	'priority' 		=> 208,
	'title'    		=> esc_html__( 'Footer Editor Options', 'helena-pro' ),
) );

$wp_customize->add_setting( 'footer_content', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['footer_content'],
	'sanitize_callback'	=> 'helena_sanitize_footer_code',
) );

$wp_customize->add_control( 'footer_content', array(
		'description' 	=> esc_html__( 'You can add custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year] and [site-link] for current year and site link respectively.', 'helena-pro' ),
		'label'			=> esc_html__( 'Footer Content', 'helena-pro' ),
        'priority'		=> 1,
		'section'   	=> 'helena_footer_options',
        'settings'  	=> 'footer_content',
		'type'			=> 'textarea',
) );

$wp_customize->add_setting( 'reset_footer_content', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['reset_footer_content'],
	'sanitize_callback' => 'helena_sanitize_checkbox',
	'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'reset_footer_content', array(
	'label'		=> esc_html__( 'Check to reset Footer Content', 'helena-pro' ),
	'priority'	=> 3,
	'settings'	=> 'reset_footer_content',
	'section'	=> 'helena_footer_options',
	'type'		=> 'checkbox',
) );
// Footer Options End

//Homepage / Frontpage Options
$wp_customize->add_section( 'helena_homepage_options', array(
	'description'	=> esc_html__( 'Only posts that belong to the categories selected here will be displayed on the front page', 'helena-pro' ),
	'panel'			=> 'helena_theme_options',
	'priority' 		=> 209,
	'title'   	 	=> esc_html__( 'Homepage / Frontpage Options', 'helena-pro' ),
) );

$wp_customize->add_setting( 'front_page_category', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['front_page_category'],
	'sanitize_callback'	=> 'helena_sanitize_category_list',
) );

$wp_customize->add_control( new helena_customize_dropdown_categories_control( $wp_customize, 'front_page_category', array(
    'label'   	=> esc_html__( 'Select Categories', 'helena-pro' ),
    'name'	 	=> 'front_page_category',
	'priority'	=> '6',
    'section'  	=> 'helena_homepage_options',
    'settings' 	=> 'front_page_category',
    'type'     	=> 'dropdown-categories',
) ) );
//Homepage / Frontpage Settings End

// Layout Options
$wp_customize->add_section( 'helena_layout', array(
	'capability'=> 'edit_theme_options',
	'panel'		=> 'helena_theme_options',
	'priority'	=> 211,
	'title'		=> esc_html__( 'Layout Options', 'helena-pro' ),
) );

$wp_customize->add_setting( 'theme_layout', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['theme_layout'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'theme_layout', array(
	'choices'  => helena_layouts(),
	'label'    => esc_html__( 'Default Layout', 'helena-pro' ),
	'section'  => 'helena_layout',
	'settings' => 'theme_layout',
	'type'     => 'select',
) );

if ( class_exists( 'woocommerce' ) ) {
	$wp_customize->add_setting( 'woocommerce_layout', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['woocommerce_layout'],
		'sanitize_callback' => 'helena_sanitize_select',
	) );

	$wp_customize->add_control( 'woocommerce_layout', array(
		'choices'  => helena_layouts(),
		'label'    => esc_html__( 'Woocommerce Layout', 'helena-pro' ),
		'section'  => 'helena_layout',
		'settings' => 'woocommerce_layout',
		'type'     => 'select',
	) );
}

$wp_customize->add_setting( 'single_page_post_layout', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['single_page_post_layout'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'single_page_post_layout', array(
	'choices'  => helena_layouts(),
	'label'    => esc_html__( 'Single Page/Post Layout', 'helena-pro' ),
	'section'  => 'helena_layout',
	'settings' => 'single_page_post_layout',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'content_layout', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['content_layout'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'content_layout', array(
	'choices'   => helena_get_archive_content_layout(),
	'label'		=> esc_html__( 'Archive Content Layout', 'helena-pro' ),
	'section'   => 'helena_layout',
	'settings'  => 'content_layout',
	'type'      => 'select',
) );

$wp_customize->add_setting( 'single_post_image_layout', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['single_post_image_layout'],
	'sanitize_callback' => 'helena_sanitize_select',
) );


$wp_customize->add_control( 'single_post_image_layout', array(
	'choices'  	=> helena_single_post_image_layout_options(),
	'label'		=> esc_html__( 'Single Page/Post Image', 'helena-pro' ),
	'section'   => 'helena_layout',
    'settings'  => 'single_post_image_layout',
    'type'	  	=> 'select',
) );
// Layout Options End

// Pagination Options
$pagination_type = apply_filters( 'helena_get_option', 'pagination_type' );

$nav_desc = sprintf(
	wp_kses(
		__( '<a target="_blank" href="%s">WP-PageNavi Plugin</a> is recommended for Numeric Option(But will work without it).<br/>Infinite Scroll Options requires <a target="_blank" href="%s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'helena-pro' ),
		array(
			'a' => array(
				'href' => array(),
				'target' => array(),
			),
			'br'=> array()
		)
	),
	esc_url( 'https://wordpress.org/plugins/wp-pagenavi' ),
	esc_url( 'https://wordpress.org/plugins/jetpack/' )
);

/**
* Check if navigation type is Jetpack Infinite Scroll and if it is enabled
*/
if ( ( 'infinite-scroll-click' == $pagination_type || 'infinite-scroll-scroll' == $pagination_type ) ) {
if ( ! (class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) ) {
	$nav_desc = sprintf(
		wp_kses(
			__( 'Infinite Scroll Options requires <a target="_blank" href="%s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'helena-pro' ),
			array(
				'a' => array(
					'href' => array(),
					'target' => array()
				)
			)
		),
		esc_url( 'https://wordpress.org/plugins/jetpack/' )
	);
}
else {
	$nav_desc = '';
}
}

$wp_customize->add_section( 'helena_pagination_options', array(
	'description'	=> $nav_desc,
	'panel'  		=> 'helena_theme_options',
	'priority'		=> 212,
	'title'    		=> esc_html__( 'Pagination Options', 'helena-pro' ),
) );

$wp_customize->add_setting( 'pagination_type', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['pagination_type'],
	'sanitize_callback' => 'helena_sanitize_select',
) );

$wp_customize->add_control( 'pagination_type', array(
	'choices'  => helena_get_pagination_types(),
	'label'    => esc_html__( 'Pagination type', 'helena-pro' ),
	'section'  => 'helena_pagination_options',
	'settings' => 'pagination_type',
	'type'	   => 'select',
) );
// Pagination Options End

// Scrollup
$wp_customize->add_section( 'helena_scrollup', array(
	'panel'    => 'helena_theme_options',
	'priority' => 215,
	'title'    => esc_html__( 'Scrollup Options', 'helena-pro' ),
) );

$wp_customize->add_setting( 'disable_scrollup', array(
	'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['disable_scrollup'],
	'sanitize_callback' => 'helena_sanitize_checkbox',
) );

$wp_customize->add_control( 'disable_scrollup', array(
	'label'		=> esc_html__( 'Check to disable Scroll Up', 'helena-pro' ),
	'section'   => 'helena_scrollup',
    'settings'  => 'disable_scrollup',
	'type'		=> 'checkbox',
) );
// Scrollup End

// Search Options
$wp_customize->add_section( 'helena_search_options', array(
	'description'=> esc_html__( 'Change default placeholder text in Search.', 'helena-pro'),
	'panel'  => 'helena_theme_options',
	'priority' => 216,
	'title'    => esc_html__( 'Search Options', 'helena-pro' ),
) );

$wp_customize->add_setting( 'search_text', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['search_text'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'search_text', array(
	'label'		=> esc_html__( 'Default Display Text in Search', 'helena-pro' ),
	'section'   => 'helena_search_options',
    'settings'  => 'search_text',
	'type'		=> 'text',
) );
// Search Options End

// Single Post Navigation
$wp_customize->add_section( 'helena_single_post_navigation', array(
	'panel'  => 'helena_theme_options',
	'priority' => 217,
	'title'    => esc_html__( 'Single Post Navigation', 'helena-pro' ),
) );

$wp_customize->add_setting( 'disable_single_post_navigation', array(
	'capability'		=> 'edit_theme_options',
    'default'			=> $defaults['disable_single_post_navigation'],
	'sanitize_callback' => 'helena_sanitize_checkbox',
) );

$wp_customize->add_control( 'disable_single_post_navigation', array(
	'label'		=> esc_html__( 'Check to disable Single Post Navigation', 'helena-pro' ),
	'section'   => 'helena_single_post_navigation',
    'settings'  => 'disable_single_post_navigation',
	'type'		=> 'checkbox',
) );
// Single Post Navigation End

// Update Notifier
$wp_customize->add_section( 'helena_update_notifier', array(
	'title'    => esc_html__( 'Update Notifier', 'helena-pro' ),
	'priority' => 217,
	'panel'    => 'helena_theme_options',
) );

$wp_customize->add_setting( 'update_notifier', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['update_notifier'],
	'sanitize_callback' => 'helena_sanitize_checkbox',
) );

$wp_customize->add_control( 'update_notifier', array(
	'label'		=> esc_html__( 'Check to disable update notifications', 'helena-pro' ),
	'section'   => 'helena_update_notifier',
    'settings'  => 'update_notifier',
	'type'		=> 'checkbox',
) );
// Update Notifier End