<?php
/**
 * The template for displaying the Featured Content
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */


if ( !function_exists( 'helena_header_highlight_content_display' ) ) :
/**
* Add Featured content.
*
* @uses action hook helena_before_content.
*
* @since Helena Pro 1.0
*/
function helena_header_highlight_content_display() {
	//helena_flush_transients();
	global $post, $wp_query;

	// get data value from options
	$enable_content = apply_filters( 'helena_get_option', 'header_highlight_content_option' );
	$content_select = apply_filters( 'helena_get_option', 'header_highlight_content_type' );

	// Front page displays in Reading Settings
	$page_on_front 	= get_option('page_on_front') ;
	$page_for_posts = get_option('page_for_posts');


	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	if ( $enable_content == 'entire-site' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable_content == 'homepage' ) ) {
		if ( !$output = get_transient( 'helena_header_highlight_content' ) ) {

			echo '<!-- refreshing cache -->';
			$classes[]      = $content_select;

			$content_number = apply_filters( 'helena_get_option', 'header_highlight_content_number' );
			$headline       = apply_filters( 'helena_get_option', 'header_highlight_content_headline' );
			$subheadline    = apply_filters( 'helena_get_option', 'header_highlight_content_subheadline' );

			$classes[]      = ' content-number-' . $content_number;

			$output ='
				<section id="header-highlights-content" class="' . esc_attr( implode( ' ', $classes ) ) . '">
					<div class="wrapper">';
						if ( $headline || $subheadline ) {
							$output .='
							<div class="header-highlight-heading-wrap">';
								if ( $headline ) {
									$output .='
									<h2 id="header-highlight-heading" class="section-title">'. $headline .'</h2>';
								}
								if ( $subheadline ) {
									$output .='
									<p>'. $subheadline .'</p>';
								}
							$output .='
							</div><!-- .header-highlight-heading-wrap -->';
						}

						$output .='
						<div class="header-highlight-content-wrap">';
							// Select content
							if ( 'demo-header-highlight-content' == $content_select ) {
								$output .= helena_demo_header_highlight_content();
							}
							elseif ( 'header-highlight-post-content' == $content_select || 'header-highlight-page-content' == $content_select || 'header-highlight-category-content' == $content_select ) {
								$output .= helena_header_highlight_post_page_category_content();
							}
							elseif ( 'header-highlight-image-content' == $content_select ) {
								$output .= helena_header_highlight_image_content();
							}
							elseif ( 'header-highlight-embed-content' == $content_select ) {
								$output .= helena_header_highlight_embed_content();
							}

			$output .='
						</div><!-- .header-highlight-content-wrap -->
					</div><!-- .wrapper -->
				</section><!-- #header-highlight-content -->';
			set_transient( 'helena_header_highlight_content', $output, 86940 );

		}
		echo $output;
	}
}
endif;
add_action( 'helena_before_content', 'helena_header_highlight_content_display', 30 );


if ( ! function_exists( 'helena_demo_header_highlight_content' ) ) :
/**
 * This function to display header highlight posts content
 *
 * @get the data value from customizer options
 *
 * @since Helena Pro 1.0
 *
 */
function helena_demo_header_highlight_content() {
	return '
	<article id="header-highlight-post-1" class="post hentry post-demo large-featured-image">
		<figure class="header-highlight-content-image">
			<a rel="bookmark" href="#">
				<img alt="Photography" class="wp-post-image" src="'.get_template_directory_uri() . '/images/highlight1-585x439.jpg" />
			</a>
		</figure>
		<div class="entry-container">
			<header class="entry-header">
				<h2 class="entry-title">
					<a href="#">Photography</a>
				</h2>
			</header>
			<footer class="entry-footer">
				<p class="entry-meta">
					<span class="cat-links">
						<span class="screen-reader-text">Categories</span>
						<a rel="category tag" href="#">Music</a>
					</span>
					<span class="posted-on">
						<span class="screen-reader-text">Posted on</span>

						<a rel="bookmark" href="#">
							<time datetime="2016-05-15T04:29:55+00:00" class="entry-date published">May 7, 2016</time>

							<time datetime="2016-05-08T08:47:27+00:00" class="updated">May 7, 2016</time>
						</a>
					</span>
				</p><!-- .entry-meta -->
			</footer>
		</div><!-- .entry-container -->
	</article>

	<article id="header-highlight-post-2" class="post hentry post-demo small-featured-image">
		<figure class="header-highlight-content-image">
			<a rel="bookmark" href="#">
				<img alt="Routes Built for Riders" class="wp-post-image" src="'.get_template_directory_uri() . '/images/highlight2-585x439.jpg" />
			</a>
		</figure>
		<div class="entry-container">
			<header class="entry-header">
				<h2 class="entry-title">
					<a href="#">Routes Built for Riders</a>
				</h2>
			</header>
			<footer class="entry-footer">
				<p class="entry-meta">
					<span class="cat-links">
						<span class="screen-reader-text">Categories</span>
						<a rel="category tag" href="#">Sports</a>
					</span>
					<span class="posted-on">
						<span class="screen-reader-text">Posted on</span>

						<a rel="bookmark" href="#">
							<time datetime="2016-05-15T04:29:55+00:00" class="entry-date published">May 7, 2016</time>

							<time datetime="2016-05-08T08:47:27+00:00" class="updated">May 7, 2016</time>
						</a>
					</span>
				</p><!-- .entry-meta -->
			</footer>
		</div><!-- .entry-container -->
	</article>

	<article id="header-highlight-post-3" class="post hentry post-demo small-featured-image">
		<figure class="header-highlight-content-image">
			<a rel="bookmark" href="#">
				<img alt="Cradle Mountain Canyons" class="wp-post-image" src="'.get_template_directory_uri() . '/images/highlight3-585x439.jpg" />
			</a>
		</figure>
		<div class="entry-container">
			<header class="entry-header">
				<h2 class="entry-title">
					<a href="#">Cradle Mountain Canyons</a>
				</h2>
			</header>
			<footer class="entry-footer">
				<p class="entry-meta">
					<span class="cat-links">
						<span class="screen-reader-text">Categories</span>
						<a rel="category tag" href="#">Sports</a>
					</span>
					<span class="posted-on">
						<span class="screen-reader-text">Posted on</span>
						<a rel="bookmark" href="#">
							<time datetime="2016-05-15T04:29:55+00:00" class="entry-date published">May 7, 2016</time>
							<time datetime="2016-05-08T08:47:27+00:00" class="updated">May 7, 2016</time>
						</a>
					</span>
				</p><!-- .entry-meta -->
			</footer>
		</div><!-- .entry-container -->
	</article>';
}
endif; // helena_demo_content


if ( ! function_exists( 'helena_header_highlight_post_page_category_content' ) ) :
/**
 * This function to display header highlight posts content
 *
 * @since Helena Pro 1.0
 */
function helena_header_highlight_post_page_category_content() {
	global $post;

	$quantity     = apply_filters( 'helena_get_option', 'header_highlight_content_number' );
	$no_of_post   = 0; // for number of posts
	$post_list    = array();// list of valid post/page ids
	$type         = apply_filters( 'helena_get_option', 'header_highlight_content_type' );
	$more_text    = apply_filters( 'helena_get_option', 'excerpt_more_text' );
	$show_content = apply_filters( 'helena_get_option', 'header_highlight_content_show' );
	$output       = '';

	$args = array(
		'post_type'           => 'any',
		'orderby'             => 'post__in',
		'ignore_sticky_posts' => 1 // ignore sticky posts
	);

	//Get valid number of posts
	if ( 'header-highlight-post-content' == $type || 'header-highlight-page-content' == $type  ) {
		for( $i = 1; $i <= $quantity; $i++ ){
			$post_id = '';

			if ( 'header-highlight-post-content' == $type ) {
				$post_id = apply_filters( 'helena_get_option', 'header_highlight_content_post_' . $i );
			}
			elseif ( 'header-highlight-page-content' == $type ) {
				$post_id = apply_filters( 'helena_get_option', 'header_highlight_content_page_' . $i );
			}

			if ( $post_id && '' != $post_id ) {
				$post_list = array_merge( $post_list, array( $post_id ) );
				$no_of_post++;
			}
		}

		$args['post__in'] = $post_list;
	}
	elseif ( 'header-highlight-category-content' == $type ) {
		$no_of_post = $quantity;

		$args['category__in'] = (array) apply_filters( 'helena_get_option', 'header_highlight_content_select_category' );
	}

	if ( 0 == $no_of_post ) {
		return;
	}

	$args['posts_per_page'] = $no_of_post;

	$get_featured_posts = new WP_Query( $args );

	$i=0;

	while ( $get_featured_posts->have_posts() ) {
		$get_featured_posts->the_post();

		$title_attribute = the_title_attribute( array( 'before' => esc_html__( 'Permalink to: ', 'helena-pro' ), 'echo' => false ) );

		$excerpt = get_the_excerpt();

		//Set image name to post-thumbnail 585x439
		$image_size		= 'post-thumbnail';

		if ( 0 == $i ) {
			$article_class	= 'large-featured-image';
		}
		else {
			$article_class	= 'small-featured-image';
		}

		$output .= '
		<article id="header-highlight-post-' . $i .'" class="post hentry header-highlight-post-content ' . $article_class . '">';
		if ( has_post_thumbnail() ) {
			//Pull post thunbnail if it is present
			$thumbnail = get_the_post_thumbnail(
				$post->ID,
				$image_size,
				array(
					'title' => $title_attribute,
					'alt' => $title_attribute
				)
			);
		}
		else {
			$first_image = helena_get_first_image(
				$post->ID,
				$image_size,
				array(
					'title' => $title_attribute,
					'alt' => $title_attribute
					)
				);

			if ( '' != $first_image ) {
				$thumbnail = $first_image;
			}
			else {
				$thumbnail = '<img class="wp-post-image" src="'.get_template_directory_uri().'/images/no-featured-image-585x439.jpg" >';
			}
		}

		$output .= '
			<figure class="header-highlight-content-image">
				<a href="' . esc_url( get_permalink() ) . '">
				'. $thumbnail .'
				</a>
			</figure>';

		$output .= '
			<div class="entry-container">
				<header class="entry-header">
					<h2 class="entry-title">
						<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . the_title( '','', false ) . '</a>
					</h2>
				</header>';

				if ( 'excerpt' == $show_content ) {
					$output .= '<div class="entry-summary"><p>' . $excerpt . '</p></div><!-- .entry-summary -->';
				}
				elseif ( 'full-content' == $show_content ) {
					$content = apply_filters( 'the_content', get_the_content() );
					$content = str_replace( ']]>', ']]&gt;', $content );
					$output .= '<div class="entry-content">' . $content . '</div><!-- .entry-content -->';
				}

				$footer_class  = '';
				$hide_category = apply_filters( 'helena_get_option', 'header_highlight_content_hide_category' );
				$hide_tags     = apply_filters( 'helena_get_option', 'header_highlight_content_hide_tags' );
				$hide_date     = apply_filters( 'helena_get_option', 'header_highlight_content_hide_date' );
				$hide_author   = apply_filters( 'helena_get_option', 'header_highlight_content_hide_author' );

				if ( $hide_category && $hide_tags && $hide_date && $hide_author ) {
					$footer_class = 'screen-reader-text';
				}

				$output .= '
				<footer class="entry-footer ' . $footer_class . '">
					' . helena_get_meta( $hide_category, $hide_tags, $hide_date, $hide_author ) . '
				</footer><!-- .entry-footer -->';

			$output .= '
			</div><!-- .entry-container -->
		</article><!-- .header-highlight-post-'. $i .' -->';

		$i++;
	}

	wp_reset_query();

	return $output;
}
endif; // $output


if ( ! function_exists( 'helena_header_highlight_image_content' ) ) :
/**
 * This function to display header highlight image content
 *
 * @since Helena Pro 1.0
 */
function helena_header_highlight_image_content() {
	$output = '';
	$quantity 		= apply_filters( 'helena_get_option',  'header_highlight_content_number'  );
	$show_content	= apply_filters( 'helena_get_option', 'header_highlight_content_show' );

	for ( $i = 1; $i <= $quantity; $i++ ) {
		$target = apply_filters( 'helena_get_option',  'header_highlight_content_target_' . $i );
		if ( $target ) {
			$target = '_blank';
		} else {
			$target = '_self';
		}

		//Checking Link
		$link = apply_filters( 'helena_get_option',  'header_highlight_content_link_' . $i );
		if ( $link ) {
			//support qTranslate plugin
			if ( function_exists( 'qtrans_convertURL' ) ) {
				$link = qtrans_convertURL( $link );
			}
		}
		else {
			$link = '#';
		}

		$title         = apply_filters( 'helena_get_option',  'header_highlight_content_title_'. $i );
		$content       = apply_filters( 'helena_get_option',  'header_highlight_content_content_'. $i );
		$button_text   = apply_filters( 'helena_get_option',  'header_highlight_content_button_text_' . $i );
		$button_link   = apply_filters( 'helena_get_option',  'header_highlight_content_button_link_' . $i );
		$button_target = apply_filters( 'helena_get_option',  'header_highlight_content_button_target_' . $i );

		if ( $button_target ) {
			$button_target = '_blank';
		} else {
			$button_target = '_self';
		}

		//Checking Button Link
		if ( $button_link ) {
			//support qTranslate plugin
			if ( function_exists( 'qtrans_convertURL' ) ) {
				$button_link = qtrans_convertURL( $button_link );
			}
		}

		if ( 1 == $i ) {
			$article_class	= 'large-featured-image';
		}
		else {
			$article_class	= 'small-featured-image';
		}

		$output .= '
		<article id="header-highlight-post-' . $i .'" class="post hentry header-highlight-image-content ' . $article_class . '">';
		$image = apply_filters( 'helena_get_option',  'header_highlight_content_image_' . $i );
			if ( $image ) {
				$output .= '
				<figure class="header-highlight-content-image">
					<a title="' . esc_attr( $title ) . '" href="' . esc_url( $link ) . '" target="' . $target . '">
						<img src="'. esc_url( $image ) .'" alt="' . esc_attr( $title ) . '" title="' . esc_attr( $title ) . '">
					</a>
				</figure>';
			}

			if ( $title || $content ) {
				$output .= '
				<div class="entry-container">';
					if ( $title ) {
						$output .= '
						<header class="entry-header">
							<h2 class="entry-title">
								<a href="' . esc_url( $link ) . '" rel="bookmark" target="'.$target.'">'.$title.'</a>
							</h2>
						</header>';
					}
					if ( 'hide-content' != $show_content || $button_link  ) {
						$output .= '<div class="entry-content">';

							if ( $content )  {
								$output .= '<p>' . $content . '</p>';
							}
							if ( $button_link ) {
								$output .= '
								<a href="'. esc_url( $button_link ).'" class="button white-button" target="'. $button_target . '">'. $button_text . '</a>';
							}
						$output .= '</div>';
					}
				$output .= '
				</div><!-- .entry-container -->';

			}
		$output .= '
		</article><!-- .header-highlight-post-'.$i.' -->';

	}
	return $output;
}
endif; //helena_header_highlight_image_content


if ( ! function_exists( 'helena_header_highlight_embed_content' ) ) :
/**
 * This function to display header highlight embed content
 *
 * @since Helena Pro 1.0
 */
function helena_header_highlight_embed_content() {
	$quantity = apply_filters( 'helena_get_option',  'header_highlight_content_number'  );

	$output = '';

	for ( $i = 1; $i <= $quantity; $i++ ) {
		if ( 1 == $i ) {
			$article_id = 'large-featured-embed';
		}
		else {
			$article_id = 'header-highlight-embed-' . ( int )  ( $i );
		}

		$output .= '
		<article id="' . $article_id . '" class="post hentry header-highlight-embed-content">';
			$embed = apply_filters( 'helena_get_option',  'header_highlight_content_embed_' . $i );

			if ( $embed ) {
				$output .= '
				<div class="entry-container">
					' . do_shortcode( $embed ) . '
				</div><!-- .entry-container -->';
			}
		$output .= '
		</article><!-- .header-highlight-embed-'.$i.' -->';

	}
	return $output;
}
endif; //helena_header_highlight_embed_content
