<?php
/**
 * Gallery Page Widget
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */


/**
 * Widget that shows selected page content and the title.
 * Construct the widget.
 * i.e. Name, description and control options.
 * Has form to ask the title, select page
 * In the display function we show the title and selected page's content.
 * If the title is not set, it shows the page title as the title.
 *
 */
class helena_gallery_page_widget extends WP_Widget {

	/**
	 * Holds widget settings defaults, populated in constructor.
	 *
	 * @var array
	 */
	protected $defaults;

	function __construct() {
		$this->defaults = array(
			'title'           => '',
			'page_id'         => '',
			'layout'     	  => 'one-column',
			'image_size'      => '',
			'disable_title'   => 0,
			'content_type'    => '',
			'content_limit'   => 200,
			'more_text'       => esc_html__( 'Read More ...', 'helena-pro' ),
		);

		$widget_ops = array(
			'classname'   => 'ct-gallery-page ctgallerypostpageimage ctfeaturedpostpageimage',
			'description' => esc_html__( 'Displays gallery page with thumbnails', 'helena-pro' ),
		);

		$control_ops = array(
			'id_base' => 'ct-gallery-page',
		);

		parent::__construct(
			'ct-gallery-page', // Base ID
			__( 'CT: Gallery Pages', 'helena-pro' ), // Name
			$widget_ops,
			$control_ops
		);
	}

 	function form( $instance ) {
 		//Defaults
 		$instance = wp_parse_args( (array) $instance, $this->defaults );
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_html_e( 'Title', 'helena-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" class="widefat" />
		</p>

        <?php /*<p>
 			<label for="<?php echo $this->get_field_id( 'page_id' ); ?>"><?php esc_html_e( 'Page', 'helena-pro' ); ?>:</label>
 			<?php
 				wp_dropdown_pages( array(
 					'name' 		=> $this->get_field_name( 'page_id' ),
 					'selected' 	=> absint( $instance['page_id'] )
 				) );
 			?>
 		</p> */ ?>
        <p>
			<label for="<?php echo $this->get_field_id( 'page_id' ); ?>"><?php esc_html_e( 'Page ID', 'helena-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'page_id' ); ?>" name="<?php echo $this->get_field_name( 'page_id' ); ?>" value="<?php echo sanitize_text_field( $instance['page_id'] ); ?>" class="widefat"/>
			<span class="description"><?php esc_html_e( 'Separate Multiple Page IDs by ,(comma)', 'helena-pro' ); ?></span>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'layout' ); ?>"><?php esc_html_e( 'Layout', 'helena-pro' ); ?>:</label>
			<select id="<?php echo $this->get_field_id( 'layout' ); ?>" name="<?php echo $this->get_field_name( 'layout' ); ?>" class="widefat">
				<?php
					$post_type_choices = array(
						'one-column'   => esc_html__( '1 Column', 'helena-pro' ),
						'two-column'   => esc_html__( '2 Column', 'helena-pro' ),
						'three-column' => esc_html__( '3 Column', 'helena-pro' ),
						'four-column'  => esc_html__( '4 Column', 'helena-pro' ),
					);

				foreach ( $post_type_choices as $key => $value ) {
					echo '<option value="' . $key . '" '. selected( $key, $instance['layout'], false ) .'>' . $value .'</option>';
				}
				?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'image_size' ); ?>"><?php esc_html_e( 'Image Size', 'helena-pro' ); ?>:</label>
			<select id="<?php echo $this->get_field_id( 'image_size' ); ?>" class="helena-image-size-selector" name="<?php echo $this->get_field_name( 'image_size' ); ?>">
				<?php
				$sizes = helena_get_additional_image_sizes();
				foreach( (array) $sizes as $name => $size )
					echo '<option value="'.esc_attr( $name ).'" '.selected( $name, $instance['image_size'], FALSE ).'>'.esc_html( $name ).' ( '.$size['width'].'x'.$size['height'].' )</option>';
				?>
			</select>
		</p>

		<p>
        	<input class="checkbox" type="checkbox" <?php checked($instance['disable_title'], true) ?> id="<?php echo $this->get_field_id( 'disable_title' ); ?>" name="<?php echo $this->get_field_name( 'disable_title' ); ?>" />
        	<label for="<?php echo $this->get_field_id('disable_title'); ?>"><?php esc_html_e( 'Check to Disable Title', 'helena-pro' ); ?></label><br />
        </p>

        <p>
			<label for="<?php echo $this->get_field_id( 'content_type' ); ?>"><?php esc_html_e( 'Content Type', 'helena-pro' ); ?>:</label>
			<select id="<?php echo $this->get_field_id( 'content_type' ); ?>" name="<?php echo $this->get_field_name( 'content_type' ); ?>">
				<option value="content" <?php selected( 'content', $instance['content_type'] ); ?>><?php esc_html_e( 'Show Content', 'helena-pro' ); ?></option>
				<option value="excerpt" <?php selected( 'excerpt', $instance['content_type'] ); ?>><?php esc_html_e( 'Show Excerpt', 'helena-pro' ); ?></option>
				<option value="content-limit" <?php selected( 'content-limit', $instance['content_type'] ); ?>><?php esc_html_e( 'Show Content Limit', 'helena-pro' ); ?></option>
				<option value="" <?php selected( '', $instance['content_type'] ); ?>><?php esc_html_e( 'No Content', 'helena-pro' ); ?></option>
			</select>
			<br />
			<label for="<?php echo $this->get_field_id( 'content_limit' ); ?>"><?php esc_html_e( 'Limit content to', 'helena-pro' ); ?>
				<input type="text" id="<?php echo $this->get_field_id( 'content_limit' ); ?>" name="<?php echo $this->get_field_name( 'content_limit' ); ?>" value="<?php echo esc_attr( intval( $instance['content_limit'] ) ); ?>" size="3" />
				<?php esc_html_e( 'characters', 'helena-pro' ); ?>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'more_text' ); ?>"><?php esc_html_e( 'More Text (if applicable)', 'helena-pro' ); ?>:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'more_text' ); ?>" name="<?php echo $this->get_field_name( 'more_text' ); ?>" value="<?php echo esc_html( $instance['more_text'] ); ?>" />
		</p>
	<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance                    = $old_instance;
		$instance['title']           = sanitize_text_field( $new_instance['title'] );
		$instance['page_id']         = sanitize_text_field( $new_instance['page_id'] );
		$instance['layout']          = sanitize_key( $new_instance['layout'] );
		$instance['image_size']      = sanitize_key( $new_instance['image_size'] );
		$instance['disable_title']   = helena_sanitize_checkbox( $new_instance['disable_title'] );
		$instance['content_type']    = sanitize_key( $new_instance['content_type'] );
		$instance['content_limit']   = absint( $new_instance['content_limit'] );
		$instance['more_text']       = sanitize_text_field( $new_instance['more_text'] );
		return $instance;
	}

	function widget( $args, $instance ) {
 		global $post, $wp_query;

		$output = $args['before_widget'];

		// Set up the author bio
		if ( ! empty( $instance['title'] ) ) {
			$output .= $args['before_title'] . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . $args['after_title'];
		}

		$query_args = array(
			'post_type'      => 'page',
			'posts_per_page' => -1
		);


		if ( '' != $instance['page_id'] ) {
			$page_id_array = explode( ',', $instance['page_id'] );
			$query_args['post__in'] = $page_id_array;
		}

		$wp_query = new WP_Query( $query_args );

		if ( have_posts() ) :
			$output .= '<div class="article-wrap gallery ' . esc_attr( $instance['layout'] ) . ' ' . esc_attr( $instance['image_size'] ) .'">';
				while ( have_posts() ) : the_post();

					$title_attribute = the_title_attribute( array( 'echo' => false ) );

					$output .= '<article class="post-'. $post->ID . ' page type-page hentry">';

						if ( has_post_thumbnail() ) {
							$output.= '
							<figure class="featured-image">
								<a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '">' .
									get_the_post_thumbnail(
										$post->ID,
										$instance['image_size']
									) .'
								</a>
							</figure>';
						}
						else {
							//Default value if there is no first image
							$image = '<img class="wp-post-image" src="'.get_template_directory_uri().'/images/no-featured-image-585x439.jpg" >';

							//Get the first image in page, returns false if there is no image
							$first_image = helena_get_first_image( $post->ID, $instance['image_size'], array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class' => 'attached-post-image' ) );

							//Set value of image as first image if there is an image present in the page
							if ( '' != $first_image ) {
								$image =	$first_image;
							}

							$output.= '
							<figure class="featured-image">
								<a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '">' . $image .'</a>
							</figure>';
						}

						$output .= '<div class="entry-container"><div class="vcenter">';

							if ( !$instance['disable_title'] ) {
								$output .= '<header class="entry-header"><h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" title="'. $title_attribute .'">'. get_the_title() .'</a></h2></header>';
							}

							if ( 'excerpt' == $instance['content_type'] ) {
								$output .= '<div class="entry-summary">';
								$output .= get_the_excerpt();
								$output .= '</div><!-- .entry-summary -->';
							}
							elseif ( 'content-limit' == $instance['content_type'] ) {
								$output .= '<div class="entry-summary">';
								$output .= helena_get_the_content_limit( (int) $instance['content_limit'], esc_html( $instance['more_text'] ) );
								$output .= '</div><!-- .entry-summary -->';
							}

							elseif ( 'content' == $instance['content_type'] ) {
								$output .= '<div class="entry-content">';
								$output .= get_the_content( esc_html( $instance['more_text'] ) );
								$output .= '</div><!-- .entry-content -->';

							}

						$output .= '</div><!-- .vcenter --></div><!-- .entry-container -->';

				$output .= '</article><!-- .type-page -->';

				endwhile;
			$output .= '</div><!-- .article-wrap -->';
		endif;

		// Reset Post Data
 		wp_reset_postdata();

 		$output .= $args['after_widget'];

		echo $output;
 	}
}

//From Codex: https://codex.wordpress.org/Widgets_API
add_action('widgets_init',
	create_function('', 'return register_widget("helena_gallery_page_widget");')
);
