<?php
/**
 * Add Custom Sidebars and Widgets
 *
 * @package Catch Themes
 * @subpackage Helena Pro
 * @since Helena Pro 1.0
 */

/**
 * Register widgetized area
 *
 * @since Helena Pro 1.0
 */
function helena_widgets_init() {
	//Primary Sidebar
	register_sidebar( array(
		'name'          => esc_html__( 'Primary Sidebar', 'helena-pro' ),
		'id'            => 'primary-sidebar',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
		'description'	=> esc_html__( 'This is the primary sidebar if you are using a two column site layout option.', 'helena-pro' ),
	) );

	$footer_no = 4; //Number of footer sidebars

	for( $i=1; $i <= $footer_no; $i++ ) {
		register_sidebar( array(
			'name'          => sprintf( esc_html__( 'Footer Area %d', 'helena-pro' ), $i ),
			'id'            => sprintf( 'footer-%d', $i ),
			'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
			'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
			'description'	=> sprintf( esc_html__( 'Footer %d widget area.', 'helena-pro' ), $i ),
		) );
	}

	// Registering 404 Error Page Content
	register_sidebar( array(
		'name'					=> esc_html__( '404 Page Not Found Content', 'helena-pro' ),
		'id' 					=> 'sidebar-notfound',
		'description'			=> esc_html__( 'Replaces the default 404 Page Not Found Content', 'helena-pro' ),
		'before_widget' 		=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  		=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'			=> '<h2 class="widget-title">',
		'after_title'			=> '</h2>',
	) );

	if ( class_exists( 'woocommerce' ) ) {
		//Optional Primary Sidebar for Shop
		register_sidebar( array(
			'name' 				=> esc_html__( 'WooCommerce Primary Sidebar', 'helena-pro' ),
			'id' 				=> 'sidebar-optional-woocommmerce',
			'description'		=> esc_html__( 'This is Optional Primary Sidebar for WooCommerce', 'helena-pro' ),
			'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
			'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
			'before_title' 		=> '<h2 class="widget-title">',
			'after_title' 		=> '</h2>'
		) );
	}

	//Optional Sidebar for Hompeage instead of main sidebar
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Homepage Sidebar', 'helena-pro' ),
		'id' 				=> 'sidebar-optional-homepage',
		'description'		=> esc_html__( 'This is Optional Sidebar for Homepage', 'helena-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );

	//Optional Sidebar for Archive instead of main sidebar
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Archive Sidebar', 'helena-pro' ),
		'id' 				=> 'sidebar-optional-archive',
		'description'		=> esc_html__( 'This is Optional Sidebar for Archive', 'helena-pro' ),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );

	//Optional Sidebar for Page instead of main sidebar
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Page Sidebar', 'helena-pro' ),
		'id' 				=> 'sidebar-optional-page',
		'description'		=> esc_html__( 'This is Optional Sidebar for Page', 'helena-pro' ),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );

	//Optional Sidebar for Post instead of main sidebar
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Post Sidebar', 'helena-pro' ),
		'id' 				=> 'sidebar-optional-post',
		'description'		=> esc_html__( 'This is Optional Sidebar for Post', 'helena-pro' ),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );

	//Optional Sidebar one for page and post
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Sidebar One', 'helena-pro' ),
		'id' 				=> 'sidebar-optional-one',
		'description'		=> esc_html__( 'This is Optional Sidebar One', 'helena-pro' ),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );

	//Optional Sidebar two for page and post
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Sidebar Two', 'helena-pro' ),
		'id' 				=> 'sidebar-optional-two',
		'description'		=> esc_html__( 'This is Optional Sidebar Two', 'helena-pro' ),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );

	//Optional Sidebar Three for page and post
	register_sidebar( array(
		'name' 				=> esc_html__( 'Optional Sidebar Three', 'helena-pro' ),
		'id' 				=> 'sidebar-optional-three',
		'description'		=> esc_html__( 'This is Optional Sidebar Three', 'helena-pro' ),
		'before_widget' 	=> '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  	=> '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title' 		=> '<h2 class="widget-title">',
		'after_title' 		=> '</h2>'
	) );
}
add_action( 'widgets_init', 'helena_widgets_init' );

/**
 * Loads up Necessary JS Scripts for widgets
 *
 * @since Helena Pro 1.0
 */
function helena_widgets_scripts( $hook) {
	if ( 'widgets.php' == $hook ) {
		wp_enqueue_style( 'helena-widgets-styles', get_template_directory_uri() . '/css/widgets.css' );
	}
}
add_action( 'admin_enqueue_scripts', 'helena_widgets_scripts' );

// Load About Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/about.php';

// Load Advertisement Code Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/advertisement-code.php';

// Load Advertisement Image Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/advertisement-image.php';

// Load Featured Embed Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/featured-embed.php';

// Load Featured Image Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/featured-image.php';

// Load Featured Page Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/featured-page.php';

// Load Featured Post Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/featured-posts.php';

// Load Gallery Image Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/gallery-image.php';

// Load Gallery Page Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/gallery-page.php';

// Load Gallery Post Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/gallery-posts.php';

// Load Instagram Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/instagram.php';

// Load Newsletter Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/newsletter.php';

// Load Social Icon Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/social-icons.php';

// Load Newsletter Widget
include trailingslashit( get_template_directory() ) . 'inc/widgets/tag-cloud.php';
